"""Version information."""
__title__ = "databricks_dbapi"
__description__ = "Databricks DBAPI."
__url__ = "https://github.com/crflynn/databricks-dbapi"
__version__ = "0.5.0"
__author__ = "Christopher Flynn"
__author_email__ = "crf204@gmail.com"
__license__ = "MIT"
__copyright__ = "Copyright 2018-2021 Christopher Flynn"
